/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {ClayInput} from '@clayui/form';
import PropType from 'prop-types';
import React from 'react';

function getDateTimeString(date) {
	const dateInstance = new Date(date);

	const dateTimeString =
		dateInstance.getFullYear() +
		'-' +
		`0${dateInstance.getMonth() + 1}`.slice(-2) +
		'-' +
		`0${dateInstance.getDate()}`.slice(-2) +
		'T' +
		`0${dateInstance.getHours()}`.slice(-2) +
		':' +
		`0${dateInstance.getMinutes()}`.slice(-2);

	return dateTimeString;
}

function InputDateTimeRenderer({updateItem, value}) {
	const formattedDate = value ? getDateTimeString(value) : '';

	return (
		<ClayInput.Group small>
			<ClayInput.GroupItem>
				<ClayInput
					onChange={(event) => {
						const newDate = new Date(event.target.value);
						const formattedDateString =
							newDate.toISOString().split('.')[0] + 'Z';
						updateItem(formattedDateString);
					}}
					type="datetime-local"
					value={formattedDate}
				/>
			</ClayInput.GroupItem>
		</ClayInput.Group>
	);
}

InputDateTimeRenderer.propTypes = {
	updateItem: PropType.func.isRequired,
	value: PropType.string,
};

export default InputDateTimeRenderer;
