/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {ClayInput} from '@clayui/form';
import PropType from 'prop-types';
import React from 'react';

function InputTextRenderer({options = {}, updateItem, value}) {
	const {appendText, inputProps, prependText} = options;

	return (
		<ClayInput.Group small>
			{prependText && (
				<ClayInput.GroupItem prepend shrink>
					{prependText}
				</ClayInput.GroupItem>
			)}
			<ClayInput.GroupItem append={appendText} prepend={prependText}>
				<ClayInput
					onChange={(event) => {
						updateItem(event.target.value);
					}}
					value={value ?? ''}
					{...inputProps}
				/>
			</ClayInput.GroupItem>
			{appendText && (
				<ClayInput.GroupItem append shrink>
					<ClayInput.GroupText>{appendText}</ClayInput.GroupText>
				</ClayInput.GroupItem>
			)}
		</ClayInput.Group>
	);
}

InputTextRenderer.propTypes = {
	options: PropType.shape({
		appendText: PropType.string,
		prependText: PropType.string,
	}),
	updateItem: PropType.func.isRequired,
	value: PropType.string,
};

export default InputTextRenderer;
