/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayList from '@clayui/list';
import classNames from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';

function TimelineEntry({date, description, title}) {
	return (
		<li className="timeline-item">
			<div className="panel panel-secondary">
				<div className="timeline-increment">
					<span className="timeline-icon"></span>
				</div>
				<div className="panel-body">
					<div className="mb-2 row">
						<div className="col">
							<h4 className="mb-0">{title}</h4>
						</div>
						<div className="col-auto">{description}</div>
					</div>
					<small>{date}</small>
				</div>
			</div>
		</li>
	);
}

TimelineEntry.propTypes = {
	date: PropTypes.string.isRequired,
	description: PropTypes.string.isRequired,
	title: PropTypes.string.isRequired,
};

TimelineEntry.defaultProps = {};

function Timeline({dataSetContext, items}) {
	return (
		<ClayList className={classNames('mb-0', 'timeline')}>
			{items.map((item, i) => (
				<TimelineEntry
					key={i}
					{...item}
					borderBottom={i !== items.length - 1}
					dataSetContext={dataSetContext}
				/>
			))}
		</ClayList>
	);
}

Timeline.propTypes = {
	dataRenderers: PropTypes.object,
	dataSetContext: PropTypes.any,
	items: PropTypes.array,
};

Timeline.defaultProps = {
	items: [],
};

export default Timeline;
